<?php

class MnglAppController
{
  function MnglAppController()
  {
    add_filter('the_content', array( $this, 'page_route' ), 1);
    //add_filter('comments_template', array( $this, 'hide_comments'), 1);
    add_action('wp_enqueue_scripts', array($this, 'load_scripts'), 1);
    add_action('init', array($this, 'access_control'), 1);
    register_activation_hook(MNGL_PATH."/mingle.php", array( $this, 'install' ));
  }
  
  /********* INSTALL PLUGIN ***********/
  function install()
  {
    global $wpdb;
    $db_version = 3; // this is the version of the database we're moving to
    $old_db_version = get_option('mngl_db_version');

    $friends_table           = $wpdb->prefix . "mngl_friends";
    $friend_requests_table   = $wpdb->prefix . "mngl_friend_requests";
    $board_posts_table       = $wpdb->prefix . "mngl_board_posts";
    $board_comments_table    = $wpdb->prefix . "mngl_board_comments";
    $attachments_table       = $wpdb->prefix . "mngl_attachments";
    $attachment_albums_table = $wpdb->prefix . "mngl_attachment_albums";

    $charset_collate = '';
    if( $wpdb->has_cap( 'collation' ) )
    {
      if( !empty($wpdb->charset) )
        $charset_collate = "DEFAULT CHARACTER SET $wpdb->charset";
      if( !empty($wpdb->collate) )
        $charset_collate .= " COLLATE $wpdb->collate";
    }

    if($db_version != $old_db_version)
    {
      require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

      /* Create/Upgrade Friends Table */
      $sql = "CREATE TABLE {$friends_table} (
                id int(11) NOT NULL auto_increment,
                user_id int(11) NOT NULL,
                friend_id int(11) NOT NULL,
                status varchar(255) DEFAULT NULL,
                created_at datetime NOT NULL,
                PRIMARY KEY  (id),
                KEY user_id (user_id),
                KEY friend_id (friend_id)
              ) {$charset_collate};";
    
      dbDelta($sql);
      
      /* Create/Upgrade Friend Requests Table */
      $sql = "CREATE TABLE {$friend_requests_table} (
                id int(11) NOT NULL auto_increment,
                user_id int(11) NOT NULL,
                friend_id int(11) NOT NULL,
                friend_record_a_id int(11) NOT NULL,
                friend_record_b_id int(11) NOT NULL,
                created_at datetime NOT NULL,
                PRIMARY KEY  (id),
                KEY user_id (user_id),
                KEY friend_id (friend_id),
                KEY friend_record_a_id (friend_record_a_id),
                KEY friend_record_b_id (friend_record_b_id)
              ) {$charset_collate};";
    
      dbDelta($sql);

      /* Create/Upgrade Board Posts Table */
      $sql = "CREATE TABLE {$board_posts_table} (
                id int(11) NOT NULL auto_increment,
                owner_id int(11) NOT NULL,
                author_id int(11) NOT NULL,
                message text DEFAULT NULL,
                type varchar(255) DEFAULT 'post',
                source varchar(255) DEFAULT NULL,
                visibility varchar(255) DEFAULT 'public',
                created_at datetime NOT NULL,
                PRIMARY KEY  (id),
                KEY owner_id (owner_id),
                KEY author_id (author_id)
              ) {$charset_collate};";
    
      dbDelta($sql);
      
      /* Create/Upgrade Board Comments Table */
      $sql = "CREATE TABLE {$board_comments_table} (
                id int(11) NOT NULL auto_increment,
                author_id int(11) NOT NULL,
                message text DEFAULT NULL,
                board_post_id int(11) NOT NULL,
                created_at datetime NOT NULL,
                PRIMARY KEY  (id),
                KEY author_id (author_id),
                KEY board_post_id (board_post_id)
              ) {$charset_collate};";
    
      dbDelta($sql);
      
      /* Create/Upgrade Attachments Table */
      $sql = "CREATE TABLE {$attachments_table} (
                id int(11) NOT NULL auto_increment,
                owner_id int(11) NOT NULL,
                name varchar(255) NOT NULL,
                url text NOT NULL,
                mime_type varchar(255) NOT NULL,
                size varchar(255) DEFAULT NULL,
                type varchar(255) DEFAULT 'photo',
                attachment_album_id int(11) DEFAULT NULL,
                created_at datetime NOT NULL,
                PRIMARY KEY  (id),
                KEY owner_id (owner_id),
                KEY attachment_album_id (attachment_album_id)
              ) {$charset_collate};";

      dbDelta($sql);
      
      /* Create/Upgrade Photo Albums Table */
      $sql = "CREATE TABLE {$attachment_albums_table} (
                id int(11) NOT NULL auto_increment,
                owner_id int(11) NOT NULL,
                type varchar(255) DEFAULT 'photos',
                created_at datetime NOT NULL,
                PRIMARY KEY  (id),
                KEY owner_id (owner_id)
              ) {$charset_collate};";
    
      dbDelta($sql);
    }

    /***** SAVE DB VERSION *****/
    //delete_option('mngl_db_version');
    //add_option('mngl_db_version',$db_version);
  }
  
  function load_scripts()
  {
    wp_enqueue_style( 'mingle', plugins_url($path = '/mingle/css/mingle.css') );
  }
  
  // Routes for wordpress pages -- we're just replacing content here folks.
  function page_route($content)
  {
    global $post, $mngl_options, $profiles_controller, $friends_controller, $action;

    switch( $post->ID )
    {  
      case $mngl_options->activity_page_id:
        $profiles_controller->activity();
        return '';
      case $mngl_options->profile_page_id:
        $profiles_controller->profile();
        return '';
      case $mngl_options->directory_page_id:
        $profiles_controller->directory($this->get_param('mdp'));
        return '';
      case $mngl_options->profile_edit_page_id:
        $profiles_controller->edit();
        return '';
      case $mngl_options->friends_page_id:
        $friends_controller->list_friends($this->get_param('mdp'));
        return '';
      case $mngl_options->friend_requests_page_id:
        $friends_controller->list_friend_requests();
        return '';
    }
      
    return $content;
  }
  
  // Routes for standalone / ajax requests
  function standalone_route($controller, $action)
  {
    global $friends_controller, $boards_controller, $profiles_controller;
    
    if($controller=='friends')
    {
      if($action=='friend_request')
        $friends_controller->friend_request($this->get_param('user_id'), $this->get_param('friend_id'));
      if($action=='delete_friend')
        $friends_controller->delete_friend($this->get_param('user_id'), $this->get_param('friend_id'));
      else if($action=='accept_friend')
        $friends_controller->accept_friend($this->get_param('request_id'));
      else if($action=='ignore_friend')
        $friends_controller->ignore_friend($this->get_param('request_id'));
    }
    else if($controller=='boards')
    {
      if($action=='post')
        $boards_controller->post($this->get_param('owner_id'), $this->get_param('author_id'), $this->get_param('message'));
      else if($action=='comment')
        $boards_controller->comment($this->get_param('board_post_id'), $this->get_param('author_id'), $this->get_param('message'));
      else if($action=='delete_post')
        $boards_controller->delete_post($this->get_param('board_post_id'));
      else if($action=='delete_comment')
        $boards_controller->delete_comment($this->get_param('board_comment_id'));
    }
    else if($controller=='activity')
    {
      if($action=='post')
        $boards_controller->post($this->get_param('owner_id'), $this->get_param('author_id'), $this->get_param('message'),true);
      else if($action=='comment')
        $boards_controller->comment($this->get_param('board_post_id'), $this->get_param('author_id'), $this->get_param('message'),true);
      else if($action=='delete_post')
        $boards_controller->delete_post($this->get_param('board_post_id'),true);
      else if($action=='delete_comment')
        $boards_controller->delete_comment($this->get_param('board_comment_id'),true);
    }
    else if($controller=='profile')
    {  
      if($action=='delete_avatar')
        $profiles_controller->delete_avatar($this->get_param('user_id'));
    }
  }
  
  // Access Controls on a Page by Page Basis
  function access_control()
  { 
    global $post, $mngl_options, $profiles_controller, $friends_controller, $action;

    switch( $post->ID )
    {  
      case $mngl_options->activity_page_id:
      case $mngl_options->profile_edit_page_id:
      case $mngl_options->friends_page_id:
      case $mngl_options->friend_requests_page_id:
        if(!is_user_logged_in())
        {
          wp_redirect(wp_login_url($_SERVER['REQUEST_URI']));
          exit;
        }  
        break;
      case $mngl_options->profile_page_id:
        if(!is_user_logged_in() and !isset($_GET['u']))
        {
          wp_redirect(wp_login_url($_SERVER['REQUEST_URI']));
          exit;
        }
    }
  }
  
  function hide_comments($template)
  {
    global $post;

    if($post->ID == $mngl_options->profile_page_id or 
       $post->ID == $mngl_options->profile_edit_page_id or
       $post->ID == $mngl_options->activity_page_id or
       $post->ID == $mngl_options->directory_page_id or
       $post->ID == $mngl_options->friends_page_id or 
       $post->ID == $mngl_options->friend_requests_page_id)
      $template = MNGL_VIEWS_PATH . "/shared/comment_template.php";
    
    return $template;
  }
  
  function get_param($param)
  {
    return (isset($_POST[$param])?$_POST[$param]:$_GET[$param]);
  }
}
?>