<?php

class MnglFriendsController
{
  function MnglFriendsController()
  {  
    add_action('wp_enqueue_scripts', array($this, 'load_scripts'), 1);
    add_filter('mngl-activity-types', array( $this, 'add_activity_types' ));
  }
  
  function add_activity_types($activity_types)
  {
    $activity_types['friendship_confirmation'] = array( 'name'    => 'Friend Confirmation',
                                                        'message' => '{$owner->first_name} is now friends with {$author_profile_link}',
                                                        'icon'    => MNGL_URL . "/images/smiley.png" );
    return $activity_types;
  }
  
  function load_scripts()
  {
    global $mngl_blogurl, $post, $mngl_options;
    
    // Only add friend css / javascript if this is one of the right pages
    if($post->ID == $mngl_options->friends_page_id or 
       $post->ID == $mngl_options->friend_requests_page_id)
    {
      wp_enqueue_style(  'mngl-profiles', plugins_url($path = '/mingle/css/mngl-friends.css'), array('mingle') );
      wp_enqueue_script( 'mingle',        plugins_url($path = '/mingle/js/mingle.js'), array('jquery') );
      wp_enqueue_script( 'mngl-boards',   plugins_url($path = '/mingle/js/mngl-friends.js'), array('mingle') );
    }
  }

  function list_friends($dir_page,$dir_page_size=50)
  {
    global $friends_controller, $mngl_friend, $mngl_user, $mngl_blogurl, $mngl_options;

    if(is_user_logged_in() and !isset($_GET['u']))
    {
      $user = $mngl_user;
      $page_params = '';
    }
    else if(isset($_GET['u']))
    {
      $user = MnglUser::get_stored_profile_by_screenname($_GET['u']);
      $page_params = '&u=' . $_GET['u'];
    }
    else
    {
      require_once MNGL_VIEWS_PATH . "/shared/unauthorized.php";
      return;
    }
    
    $user_avatar_url = $user->get_avatar_url();
    $user_avatar_dim = $user->get_avatar_dimensions(75);
    
    $dir_page = (empty($dir_page)?0:($dir_page-1));
    $dir_offset = $dir_page * $dir_page_size;
    $friends = MnglFriend::get_friends_user_array($user->id,$dir_offset,$dir_page_size);

    $num_pages = MnglFriend::get_friend_count($user->id, "status='verified'") / $dir_page_size;

    $prev_page = $dir_page;
    $next_page = ((($dir_page+1) >= $num_pages)?0:($dir_page + 2));
    
    $friends_page_url = get_permalink($mngl_options->friend_page_id);
    $param_char = ((preg_match("#\?#",$friends_page_url))?'&':'?');
  
    if($friends)
      require_once MNGL_VIEWS_PATH . "/mngl-friends/list.php";
    else
      require_once MNGL_VIEWS_PATH . "/mngl-friends/no_friends_found.php";
  }
  
  function list_friend_requests()
  {  
    global $current_user, $mngl_friend;
    if(is_user_logged_in())
    {
      get_currentuserinfo();
    
      $requests = $mngl_friend->get_friend_requests($current_user->ID);
    
      require_once MNGL_VIEWS_PATH . "/mngl-friends/requests.php"; 
    }
    else
      require_once MNGL_VIEWS_PATH . "/shared/unauthorized.php";
  }
  
  function accept_friend($request_id)
  {
    if(is_user_logged_in())
    {
      global $mngl_friend, $mngl_board_post;
      
      $mngl_friend->accept_friend($request_id);
      
      $request = $mngl_friend->get_friend_request($request_id);
      
      // Put an activity entry on both boards...
      $mngl_board_post->add_activity_by_id( $request->user_id, $request->friend_id, 'friendship_confirmation' );
      $mngl_board_post->add_activity_by_id( $request->friend_id, $request->user_id, 'friendship_confirmation' );

      $mngl_friend->delete_request( $request_id );
    }
  }
  
  function ignore_friend($request_id)
  {
    if(is_user_logged_in())
    {
      global $mngl_friend;
      
      $mngl_friend->ignore_friend($request_id, $current_user);
    }
  }
  
  function display_add_friend_button($user_id, $friend_id)
  {
    if(is_user_logged_in())
    {
      global $current_user, $mngl_friend;
  
      get_currentuserinfo();
    
      if($user_id == $friend_id)
      {
        require MNGL_VIEWS_PATH . "/mngl-friends/me.php";
        return;
      }
    
      $friend = $mngl_friend->get_one_by_user_ids($user_id, $friend_id);
  
      if($friend)
      {
        if($friend->status == 'verified')
          require MNGL_VIEWS_PATH . "/mngl-friends/already_friend.php";
        else 
          require MNGL_VIEWS_PATH . "/mngl-friends/friend_requested.php";
      }
      else
      {
        require MNGL_VIEWS_PATH . "/mngl-friends/add_button.php";
      }
    }
  }
  
  function friend_request($user_id,$friend_id)
  {
    global $mngl_user, $mngl_friend;
    
    if($mngl_user->is_logged_in_and_current_user($user_id))
      return $mngl_friend->request_friend( $user_id, $friend_id );
  }
  
  function delete_friend($user_id,$friend_id)
  {
    global $mngl_user, $mngl_friend;
    
    if($mngl_user->is_logged_in_and_current_user($user_id))
      return $mngl_friend->delete_both($user_id,$friend_id);
  }
  
  function display_friends_grid($user_id,$cols=3,$rows=2)
  {
    global $mngl_friend;
    
    $grid_cell_count = $cols * $rows;
    $user_count = $mngl_friend->get_friend_count($user_id, "status='verified'");
    $owner = MnglUser::get_stored_profile_by_id($user_id);
    $user_type = 'friends';
    $all_users_url = $owner->get_friends_url();
    
    // Grab a random selection of friends from the database
    $users = $mngl_friend->get_friends_user_array( $user_id, 0, $grid_cell_count, 'RAND()' );
    require MNGL_VIEWS_PATH . "/shared/user_grid.php";
  }
}
?>