<?php

class MnglProfilesController
{
  function MnglProfilesController()
  {
    add_action('wp_enqueue_scripts', array($this, 'load_scripts'), 1);
    add_filter('mngl-activity-types', array( $this, 'add_activity_types' ));
  }
  
  function add_activity_types($activity_types)
  {
    $activity_types['profile_updates'] = array( 'name'    => 'Profile Updates',
                                                'message' => '{$owner->first_name} updated {$owner->his_her} profile',
                                                'icon'    => MNGL_URL . "/images/smiley.png" );
    return $activity_types;
  }
  
  function load_scripts()
  {
    global $post, $mngl_options;
    
    if($post->ID == $mngl_options->profile_page_id or 
       $post->ID == $mngl_options->profile_edit_page_id or
       $post->ID == $mngl_options->activity_page_id or
       $post->ID == $mngl_options->directory_page_id)
    {
      wp_enqueue_style(  'mngl-profiles', plugins_url($path = '/mingle/css/mngl-profiles.css'), array('mingle') );
      wp_enqueue_style(  'mngl-boards',   plugins_url($path = '/mingle/css/mngl-boards.css'), array('mingle') );
      wp_enqueue_script( 'mingle',        plugins_url($path = '/mingle/js/mingle.js'), array('jquery') );
      wp_enqueue_script( 'mngl-boards',   plugins_url($path = '/mingle/js/mngl-boards.js'), array('mingle') );
      wp_enqueue_script( 'mngl-profiles', plugins_url($path = '/mingle/js/mngl-profiles.js'), array('mingle') );
    }
  }
  
  function directory($dir_page,$dir_page_size=50)
  {
    $dir_page = (empty($dir_page)?0:($dir_page-1));
    $dir_offset = $dir_page * $dir_page_size;
    $profiles = MnglUser::get_stored_profiles($dir_offset,$dir_page_size);
    
    $num_pages = MnglUser::get_count() / $dir_page_size;
    
    $prev_page = $dir_page;
    $next_page = ((($dir_page+1) >= $num_pages)?0:($dir_page + 2));
    require_once MNGL_VIEWS_PATH . "/mngl-profiles/directory.php";
  }

  function profile()
  {
    global $friends_controller, $boards_controller, $app_helper, $mngl_blogurl;

    if(is_user_logged_in() and !isset($_GET['u']))
    {
      $user = MnglUser::get_stored_profile();
      $avatar_url = $user->get_avatar_url();
      $avatar_dimensions = $user->get_avatar_dimensions(200);
      require_once MNGL_VIEWS_PATH . "/mngl-profiles/profile.php";
    }
    else if(isset($_GET['u']))
    {
      $screenname = $_GET['u'];
      $user = MnglUser::get_stored_profile_by_screenname($screenname);
      $avatar_url = $user->get_avatar_url();
      $avatar_dimensions = $user->get_avatar_dimensions(200);
      require_once MNGL_VIEWS_PATH . "/mngl-profiles/profile.php";
    }
    else
      require_once MNGL_VIEWS_PATH . "/shared/unauthorized.php";
  }
  
  function activity()
  {
    global $friends_controller, $boards_controller, $app_helper, $mngl_blogurl;

    if(is_user_logged_in())
    {
      $user = MnglUser::get_stored_profile();
      require_once MNGL_VIEWS_PATH . "/mngl-profiles/activity.php";
    }
    else
      require_once MNGL_VIEWS_PATH . "/shared/unauthorized.php";
  }

  function edit()
  {
    if(is_user_logged_in())
    {
      global $mngl_user, $mngl_blogurl, $mngl_board_post;
      
      $avatar_url = $mngl_user->get_avatar_url();
      $avatar_dim = $mngl_user->get_avatar_dimensions(100);
      
      if(isset($_POST['action']) and $_POST['action'] == 'process_form')
      {
        $mngl_user->update($_POST);
        $mngl_user->store();

        $avatar_url = $mngl_user->get_avatar_url();
        $avatar_dim = $mngl_user->get_avatar_dimensions(100);
        
        do_action('mngl-profile-update');

        $mngl_board_post->add_activity_by_id( $mngl_user->id, $mngl_user->id, 'profile_updates' );

        require_once MNGL_VIEWS_PATH . "/mngl-profiles/profile_saved.php";
      }
      
      require_once MNGL_VIEWS_PATH . "/mngl-profiles/edit.php";
    }
    else
      require_once MNGL_VIEWS_PATH . "/shared/unauthorized.php";
  }
  
  function display_status($user_id)
  {
    global $app_helper;
    
    $user = MnglUser::get_stored_profile_by_id($user_id);
    
    require_once MNGL_VIEWS_PATH . "/mngl-profiles/profile_status.php";
  }
  
  function delete_avatar($user_id)
  {
    global $mngl_user;
    
    if(is_user_logged_in() and $user_id==$mngl_user->id)
    {
      $mngl_user->avatar = '';
      $mngl_user->store();
      
      $avatar_url = $mngl_user->get_avatar_url();
      $avatar_dim = $mngl_user->get_avatar_dimensions(100);
      require_once MNGL_VIEWS_PATH . "/mngl-profiles/edit_avatar.php";
    }
  }
}
?>
