<?php

class MnglUser
{ 
  var $profile_name;
  
  var $id; // ID from the current user record
  var $avatar;
  var $avatar_meta;
  var $db_first_name; // For database use only
  var $db_last_name; // For database use only
  var $screenname;
  var $email;
  var $url;
  var $location;
  var $sex;
  var $bio;
  var $fields;
  
  var $id_str;
  var $avatar_str;
  var $first_name_str;
  var $last_name_str;
  var $screenname_str;
  var $email_str;
  var $url_str;
  var $location_str;
  var $sex_str;
  var $bio_str;
  var $fields_str;
  
  var $full_name;
  var $first_name;
  var $last_name;
  var $his_her; // calculated from $sex var
  var $him_her; // calculated from $sex var
  var $he_she; // calculated from $sex var

  // Notification Settings
  var $hide_notifications;
  
  var $hide_notifications_str;
  
  // Privacy Settings
  var $privacy;
  
  var $privacy_str;

  function MnglUser( $id = '')
  {
    $this->set_default_options( $id );
  }

  function set_default_options( $id = '' )
  {
    global $mngl_options, $current_user;
    get_currentuserinfo();
    
    if( empty($id) )
      $user = $current_user;
    else
      $user = get_userdata($id);
    
    // We're abstracting and simplifying user objects here
    $this->id         = $user->ID;
    $this->screenname = $user->user_login;
    $this->email      = $user->user_email;
    $this->url        = $user->user_url;

    // Set string keys
    $this->profile_name           = 'mngl_user_profile';
    $this->id_str                 = 'mngl_user_id';
    $this->avatar_str             = 'mngl_user_avatar';
    $this->first_name_str         = 'mngl_user_first-name';
    $this->last_name_str          = 'mngl_user_last-name';
    $this->screenname_str         = 'mngl_user_screenname';
    $this->email_str              = 'mngl_user_email';
    $this->url_str                = 'mngl_user_url';
    $this->location_str           = 'mngl_user_location';
    $this->sex_str                = 'mngl_user_sex';
    $this->bio_str                = 'mngl_user_bio';
    $this->fields_str             = 'mngl_user_fields';
    $this->hide_notifications_str = 'mngl_user_hide_notifications';
    $this->privacy_str            = 'mngl_user_privacy';
    
    // Get some metadata aggregated dogg!
    $this->db_first_name      = get_usermeta($user->ID, 'first_name' );
    $this->db_last_name       = get_usermeta($user->ID, 'last_name' );
    $this->avatar             = get_usermeta($user->ID, 'mngl_avatar' );
    $this->location           = get_usermeta($user->ID, 'mngl_location' );
    $this->sex                = get_usermeta($user->ID, 'mngl_sex' );
    $this->bio                = get_usermeta($user->ID, 'description' );
    $this->fields             = get_usermeta($user->ID, 'mngl_fields' );
    $this->hide_notifications = get_usermeta($user->ID, $this->hide_notifications_str );
    $this->privacy            = get_usermeta($user->ID, $this->privacy_str );

    // Set Defaults
    if(!isset($this->hide_notifications) or !is_array($this->hide_notifications))
      $this->hide_notifications = array();

    if(!isset($this->privacy) or !$this->privacy)
      $this->privacy = 'private';

    if(!isset($this->avatar) or !$this->avatar)
      $this->avatar = '';

    if(!isset($this->sex) or !$this->sex)
      $this->sex = '';

    if(!isset($this->fields) or !$this->fields)
      $this->fields = array();
    
    // Calculate meta data settings
    if( $mngl_options->display_name_type == 'fullname' and 
        !empty( $this->db_first_name ) and 
        !empty( $this->db_last_name ) )
    {
      $this->full_name  = "{$this->db_first_name} {$this->db_last_name}";
      $this->first_name = $this->db_first_name;
      $this->last_name  = $this->db_last_name;
    }
    else
    {
      $this->full_name  = $this->screenname;
      $this->first_name = $this->screenname;
      $this->last_name  = $this->screenname;
    }
    
    // Calculate pronouns to use depending on gender
    if($this->sex == 'female')
    {
      $this->his_her = 'Her';
      $this->him_her = 'Her';
      $this->he_she = 'She';
    }
    else if($this->sex == 'male')
    {
      $this->his_her = 'His';
      $this->him_her = 'Him';
      $this->he_she = 'He';
    }
    else
    {
      $this->his_her = 'His/Her';
      $this->him_her = 'Him/Her';
      $this->he_she = 'He/She';
    }
  }
  
  function validate($params,$errors)
  {   
    return $errors;
  }
  
  function update($params)
  {
    global $mngl_options;
    
    // Only the current user can modify his/her own profile
    if($this->is_logged_in_and_current_user($this->id))
    { 
      $this->id                 = (int)$params[ $this->id_str ];
      $this->db_first_name      = $params[ $this->first_name_str ];
      $this->db_last_name       = $params[ $this->last_name_str ];
      $this->screenname         = $params[ $this->screenname_str ];
      $this->email              = $params[ $this->email_str ];
      $this->url                = $params[ $this->url_str ];
      $this->location           = $params[ $this->location_str ];
      $this->sex                = $params[ $this->sex_str ];
      $this->bio                = $params[ $this->bio_str ];
      $this->fields             = $params[ $this->fields_str ];
      $this->hide_notifications = $params[ $this->hide_notifications_str ];
      $this->privacy            = $params[ $this->privacy_str ];
      
      // Upload the avatar 
      if( isset($_FILES[ $this->avatar_str ]) and 
          !empty($_FILES[ $this->avatar_str ]['name']) and
          (int)$_FILES[ $this->avatar_str ]['size'] > 0 )
      {
        $target_path = get_option('upload_path');
        if(!file_exists($target_path))
          @mkdir($target_path."/");
      
        $target_path = $target_path . "/mingle";
        if(!file_exists($target_path))
          @mkdir($target_path."/");
    
        $target_path = $target_path . "/avatars";
        if(!file_exists($target_path))
          @mkdir($target_path."/");
      
        $target_path = $target_path . '/' . basename( $_FILES[ $this->avatar_str ]['name']);
      
        move_uploaded_file($_FILES[ $this->avatar_str ]['tmp_name'], $target_path);
      
        $this->avatar = preg_replace('#'.ABSPATH.'#','',$target_path);
        $this->avatar_meta = getimagesize($this->avatar);
      }
    }
  }
  
  function store()
  {
    global $wpdb;
    
    // Only the current user can store his/her own profile
    if($this->is_logged_in_and_current_user($this->id))
    {
      // Update User Table Fields
      $query = "UPDATE {$wpdb->prefix}users SET user_login=%s, user_email=%s, user_url=%s WHERE id=%d";
      $query = $wpdb->prepare($query, $this->screenname, $this->email, $this->url, $this->id);
      $wpdb->query($query);
      
      // Update User Meta Fields
      update_usermeta( $this->id, 'first_name',         $this->db_first_name );
      update_usermeta( $this->id, 'last_name',          $this->db_last_name );
      update_usermeta( $this->id, 'mngl_avatar',        $this->avatar );
      update_usermeta( $this->id, 'mngl_avatar_meta',   $this->avatar_meta );
      update_usermeta( $this->id, 'mngl_location',      $this->location );
      update_usermeta( $this->id, 'mngl_sex',           $this->sex );
      update_usermeta( $this->id, 'description',        $this->bio );
      update_usermeta( $this->id, 'mngl_fields',        $this->fields );
      
      update_usermeta( $this->id, $this->hide_notifications_str, $this->hide_notifications );
      update_usermeta( $this->id, $this->privacy_str,            $this->privacy );
    }
  }
  
  function get_all( $where='', $order_by='', $limit='' )
  {
    global $wpdb, $mngl_friend;
    
    $where    = ((empty($where))?'':" WHERE {$where}");
    $order_by = ((empty($order_by))?'':" ORDER BY {$order_by}");
    $limit    = ((empty($limit))?'':" LIMIT {$limit}");
    
    $query_str = "SELECT * FROM {$wpdb->prefix}users{$where}{$order_by}{$limit}";
    $query = $wpdb->prepare( $query_str, $user_id );

    return $wpdb->get_results($query);
  }
  
  function get_user_array( $offset=0, $limit=50, $order_by='' )
  {
    global $wpdb;

    if( MnglUser::get_count() <= 0 )
      return false;

    $users = MnglUser::get_all( '', $order_by, "{$offset},{$limit}" );

    $users_a = array();
    
    foreach ($users as $user) 
      $users_a[] = MnglUser::get_stored_profile_by_id($user->ID);
    
    return $users_a;
  }
  
  function get_avatar_url()
  {
    global $mngl_blogurl;
    
    if(empty($this->avatar))
    {  
      $mystery_url = MNGL_URL . "/images/mystery_avatar.png";
      if(!empty($this->email))
      {
        $email_hash = md5(trim(strtolower($this->email)));
        return "http://www.gravatar.com/avatar/{$email_hash}.jpg?s=200&d=".urlencode($mystery_url);
      }
      else
        return $mystery_url;
    }
    else
      return "{$mngl_blogurl}/{$this->avatar}";
  }
  
  function get_avatar_meta()
  {
    if(!isset($this->avatar_meta) or empty($this->avatar_meta))
    {
      if(!empty($this->avatar))
        $this->avatar_meta = getimagesize( ABSPATH . "/" . $this->avatar );
    }
    else
      $this->avatar_meta = ''; 
    
    return $this->avatar_meta;
  }
  
  function get_avatar_mime_type()
  {
    $avmeta = $this->get_avatar_meta();
    if(!empty($avmeta))
      return $avmeta['mime'];
    else
      return '';
  }
  
  function get_avatar_dimensions($constrain_width=0,$constrain_height=0)
  {
    $avmeta = $this->get_avatar_meta();

    if(!empty($avmeta))
    {
      $real_width  = $avmeta[0];
      $real_height = $avmeta[1];

      if($constrain_width==0 and $constrain_height==0)
        return array( "width" => $real_width, "height" => $real_height );
      else if($constrain_width==0 and $constrain_height > 0)
        return array( "width" => (int)(( (float)$constrain_height / (float)$real_height ) * (float)$real_width ), "height" => $constrain_height );
      else if($constrain_width > 0 and $constrain_height == 0)
        return array( "width" => $constrain_width, "height" => (int)(( (float)$constrain_width / (float)$real_width ) * (float)$real_height ) );
      else
        return array( "width" => $constrain_width, "height" => $constrain_height );
    }
    else
    {
      if( $constrain_width==0 and $constrain_height==0 )
        return array( "width" => 1, "height" => 1 );
      else if( $constrain_width==0 and $constrain_height > 0 )
        return array( "width" => $constrain_height, "height" => $constrain_height );
      else if( $constrain_width > 0 and $constrain_height == 0 )
        return array( "width" => $constrain_width, "height" => $constrain_width );
      else
        return array( "width" => $constrain_width, "height" => $constrain_height );
    }
  }
  
  function get_profile_url()
  {
    global $mngl_options;
    
    if(isset($mngl_options->profile_page_id) and $mngl_options->profile_page_id != 0)
    {
      $permalink = get_permalink($mngl_options->profile_page_id);
      $param_char = ((preg_match("#\?#",$permalink))?'&':'?');
      return "{$permalink}{$param_char}u={$this->screenname}";
    }
    
    return '';
  }
  
  function get_friends_url()
  {
    global $mngl_options;

    if(isset($mngl_options->friends_page_id) and $mngl_options->friends_page_id != 0)
    {
      $permalink = get_permalink($mngl_options->friends_page_id);
      $param_char = ((preg_match("#\?#",$permalink))?'&':'?');
      return "{$permalink}{$param_char}u={$this->screenname}";
    }
    
    return '';
  }
  
  function update_status($status)
  {  
    if(!empty($status))
    {
      update_usermeta( $this->id, 'mngl-user-status',  $status );
      update_usermeta( $this->id, 'mngl-user-status-time', date('c') );
    }
  }
  
  function get_status()
  {
    return get_usermeta( $this->id, 'mngl-user-status' );
  }
  
  function get_status_time()
  {
    return get_usermeta( $this->id, 'mngl-user-status-time' );
  }
  
  function get_stored_profile_by_id($user_id = '')
  {
    $user = '';

    if(!empty($user_id))
      $user = get_userdata($user_id);
    
    return MnglUser::get_stored_profile($user);
  }
  
  function get_stored_profile_by_screenname($screenname = '')
  {
    $user = '';
    
    if(!empty($screenname))
      $user = get_userdatabylogin($screenname);
    
    return MnglUser::get_stored_profile($user);
  }
  
  function get_stored_profile($user = '')
  {
    if(empty($user))
    {
      global $current_user;
      get_currentuserinfo();
      $user = $current_user;
    }
    
    return new MnglUser($user->ID);
  }
  
  function get_stored_profiles($offset=0, $limit=50)
  {
    global $wpdb;
    
    $query = "SELECT ID FROM {$wpdb->prefix}users ORDER BY user_login ASC LIMIT {$offset},{$limit}";
    $user_ids = $wpdb->get_col($query,0);
    $profiles = array();
    
    foreach ($user_ids as $user_id)
      $profiles[] = MnglUser::get_stored_profile_by_id($user_id);
    
    return $profiles;
  }
  
  function get_count()
  {
    global $wpdb;

    $query = "SELECT COUNT(*) FROM {$wpdb->prefix}users";
    
    return $wpdb->get_var($query);
  }
  
  function is_logged_in_and_current_user($user_id)
  {
    global $current_user;
    get_currentuserinfo();

    return (is_user_logged_in() and ($current_user->ID == $user_id));
  }
}
?>
